summaryrefslogtreecommitdiff
path: root/indra/newview/llfloaterfriends.h
diff options
context:
space:
mode:
Diffstat (limited to 'indra/newview/llfloaterfriends.h')
-rw-r--r--indra/newview/llfloaterfriends.h10
1 files changed, 6 insertions, 4 deletions
diff --git a/indra/newview/llfloaterfriends.h b/indra/newview/llfloaterfriends.h
index a5c94ee485..51fe5f6d89 100644
--- a/indra/newview/llfloaterfriends.h
+++ b/indra/newview/llfloaterfriends.h
@@ -83,6 +83,9 @@ public:
static void requestFriendship(const LLUUID& target_id,
const std::string& target_name, const std::string& message);
+ // *HACK Made public to remove friends from LLAvatarIconCtrl context menu
+ static bool handleRemove(const LLSD& notification, const LLSD& response);
+
private:
enum FRIENDS_COLUMN_ORDER
@@ -115,15 +118,15 @@ private:
void confirmModifyRights(rights_map_t& ids, EGrantRevoke command);
void sendRightsGrant(rights_map_t& ids);
- // return LLUUID::null if nothing is selected
- LLDynamicArray<LLUUID> getSelectedIDs();
+ // return empty vector if nothing is selected
+ std::vector<LLUUID> getSelectedIDs();
// callback methods
static void onSelectName(LLUICtrl* ctrl, void* user_data);
static bool callbackAddFriend(const LLSD& notification, const LLSD& response);
static bool callbackAddFriendWithMessage(const LLSD& notification, const LLSD& response);
static void onPickAvatar(const std::vector<std::string>& names, const std::vector<LLUUID>& ids, void* user_data);
- static void onMaximumSelect(void* user_data);
+ static void onMaximumSelect();
static void onClickIM(void* user_data);
static void onClickProfile(void* user_data);
@@ -135,7 +138,6 @@ private:
static void onClickModifyStatus(LLUICtrl* ctrl, void* user_data);
- static bool handleRemove(const LLSD& notification, const LLSD& response);
bool modifyRightsConfirmation(const LLSD& notification, const LLSD& response, rights_map_t* rights);
private: